@@ -1,11 +1,13 @@
 #include "SymbianCallInitiator.h"
 #include "SymbianCallInitiatorPrivate.h"
 #include "SymbianCallObserverPrivate.h"
+#include "SymbianDTMFPrivate.h"
 
 SymbianCallInitiator::SymbianCallInitiator (QObject *parent)
 : CalloutInitiator(parent)
 , dialer (NULL)
 , observer (NULL)
+, dtmfSender (new SymbianDTMFPrivate (this))
 {
 }//SymbianCallInitiator::SymbianCallInitiator
 
@@ -17,6 +19,9 @@ SymbianCallInitiator::~SymbianCallInitiator()
     if (NULL != dialer) {
         delete dialer;
     }
+    if (NULL != dtmfSender) {
+        delete dtmfSender;
+    }
 }//SymbianCallInitiator::~SymbianCallInitiator
 
 QString
@@ -39,7 +44,7 @@ SymbianCallInitiator::isValid ()
 
 void
 SymbianCallInitiator::initiateCall (const QString &strDestination,
-                                    void *ctx = NULL)
+                                    void *ctx /*= NULL*/)
 {
     bool bOk = false;
     m_Context = ctx;
@@ -92,7 +97,7 @@ SymbianCallInitiator::callDone (SymbianCallInitiatorPrivate *self, int status)
 }//SymbianCallInitiator::callDone
 
 void
-SymbianCallInitiator::callInitiated ()
+SymbianCallInitiator::onCallInitiated ()
 {
     bool bObserving = false;
     {
@@ -105,11 +110,42 @@ SymbianCallInitiator::callInitiated ()
     if (bObserving) {
         emit callDialed();
     }
-}//SymbianCallInitiator::callInitiated
+}//SymbianCallInitiator::onCallInitiated
 
 bool
 SymbianCallInitiator::sendDTMF (const QString &strTones)
 {
-    //@@UV: Add DTMF to Symbian
-    return false;
+    arrTones.clear ();
+    arrTones = strTones.split ('p');
+
+    nextDtmf ();
+    return true;
 }//SymbianCallInitiator::sendDTMF
+
+void
+SymbianCallInitiator::onDtmfSent (SymbianDTMFPrivate *self, bool bSuccess)
+{
+    qDebug() << "Send DTMF " << (bSuccess ? "suceeded" : "failed");
+    QTimer::singleShot (1000, this, SLOT(nextDtmf ()));
+}//SymbianCallInitiator::onDtmfSent
+
+void
+SymbianCallInitiator::nextDtmf()
+{
+    if (arrTones.isEmpty ()) {
+        qDebug ("No more tones");
+        return;
+    }
+
+    QString strTones = arrTones.first ();
+    arrTones.pop_front ();
+
+    if (strTones.isEmpty ()) {
+        qDebug ("Blank tone");
+        QTimer::singleShot (1000, this, SLOT(nextDtmf ()));
+    } else {
+        qDebug () << "Current tone =" << strTones;
+
+        dtmfSender->sendDTMF (strTones);
+    }
+}//SymbianCallInitiator::nextDtmf
